@@ -5,8 +5,8 @@ from typing import Dict, Union, Any
 from allennlp.common import Params
 from allennlp.predictors import Predictor
 
-from allennlp_models.common.model_card import ModelCard
-from allennlp_models.common.task_card import TaskCard
+from allennlp.common.model_card import ModelCard
+from allennlp.common.task_card import TaskCard
 
 # These imports are included so that the model cards can be filled with default information
 # obtained from the registered model classes.
